/*  tds200mt
 *  Copyright (C) 1999 Alvaro De Amicis
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#include <math.h>
#include "graphics.h"

extern GraphOpts graphic_options;


void 
draw_grid (GtkWidget * widget,
		   GdkPixmap * pixmap)
{
	GdkRectangle rect;
	GdkGC *gc;
	int i;

	gc = gdk_gc_new (widget->window);

	gdk_gc_set_line_attributes (gc, 1, GDK_LINE_SOLID,
								GDK_CAP_NOT_LAST, GDK_JOIN_MITER);

	gdk_draw_line (pixmap,
				   gc,
				   0, 128,
				   250, 128);
	gdk_draw_line (pixmap,
				   gc,
				   125, 0,
				   125, 255);

	gdk_gc_set_line_attributes (gc, 1, GDK_LINE_ON_OFF_DASH,
								GDK_CAP_NOT_LAST, GDK_JOIN_MITER);

	gdk_draw_line (pixmap, gc, 0, 26, 250, 26);
	gdk_draw_line (pixmap, gc, 0, 51, 250, 51);
	gdk_draw_line (pixmap, gc, 0, 77, 250, 77);
	gdk_draw_line (pixmap, gc, 0, 102, 250, 102);
	gdk_draw_line (pixmap, gc, 0, 128, 250, 128);
	gdk_draw_line (pixmap, gc, 0, 154, 250, 154);
	gdk_draw_line (pixmap, gc, 0, 179, 250, 179);
	gdk_draw_line (pixmap, gc, 0, 205, 250, 205);
	gdk_draw_line (pixmap, gc, 0, 230, 250, 230);
	for (i = 25; i < 250; i += 25)
		gdk_draw_line (pixmap, gc, i, 0, i, 255);

	rect.x = 0;
	rect.y = 0;
	rect.width = widget->allocation.width;
	rect.height = widget->allocation.height;
	gtk_widget_draw (widget, &rect);
}


void
draw_waveform (GtkWidget *widget,
			   GdkPixmap *pixmap,
			   TdsWave   *wf)
{
	GdkRectangle rect;
	GdkGC *gc;
	GdkFont *font;
	int i;
	

	gc = gdk_gc_new (widget->window);

	gdk_gc_set_line_attributes (gc, 3, GDK_LINE_SOLID,
								GDK_CAP_NOT_LAST, GDK_JOIN_MITER);

	for (i = 0; i < 2499; ++i )
		gdk_draw_line (pixmap, gc, i/10, 255-wf->WFMdata[i],
						(i+1)/10, 255-wf->WFMdata[i+1]); 

	font = gdk_font_load(
			"-*-helvetica-bold-r-normal--*-120-*-*-*-*-*-*");
	if (desctoid(wf->WFMPreWFid, wf->ID) == 0)
		gdk_draw_string (pixmap, font, gc, 10, 10, wf->ID);
		 
	rect.x = 0;
	rect.y = 0;
	rect.width = widget->allocation.width;
	rect.height = widget->allocation.height;
	gtk_widget_draw (widget, &rect);
}


void
set_drawing_area (GtkWidget *widget,
                  GdkPixmap *pixmap)
{
/*	GdkRectangle rect;*/
	GdkGC *gc;
	int i;
	
	gc = widget->style->black_gc;

	gdk_draw_rectangle (pixmap,
						gc,
						TRUE, 0, 0,
						widget->allocation.width,
						widget->allocation.height);

	gdk_gc_set_line_attributes (gc, 1, GDK_LINE_SOLID,
								GDK_CAP_NOT_LAST, GDK_JOIN_MITER);

	gc = widget->style->white_gc;

	gdk_draw_line (pixmap,
				   gc,
				   0, 128,
				   250, 128);
	gdk_draw_line (pixmap,
				   gc,
				   125, 0,
				   125, 255);

	gdk_gc_set_line_attributes (gc, 1, GDK_LINE_ON_OFF_DASH,
								GDK_CAP_NOT_LAST, GDK_JOIN_MITER);

	gdk_draw_line (pixmap, gc, 0, 26, 250, 26);
	gdk_draw_line (pixmap, gc, 0, 51, 250, 51);
	gdk_draw_line (pixmap, gc, 0, 77, 250, 77);
	gdk_draw_line (pixmap, gc, 0, 102, 250, 102);
	gdk_draw_line (pixmap, gc, 0, 128, 250, 128);
	gdk_draw_line (pixmap, gc, 0, 154, 250, 154);
	gdk_draw_line (pixmap, gc, 0, 179, 250, 179);
	gdk_draw_line (pixmap, gc, 0, 205, 250, 205);
	gdk_draw_line (pixmap, gc, 0, 230, 250, 230);
	for (i = 25; i < 250; i += 25)
		gdk_draw_line (pixmap, gc, i, 0, i, 255);

/*	rect.x = 0;
	rect.y = 0;
	rect.width = widget->allocation.width;
	rect.height = widget->allocation.height;
	gtk_widget_draw (widget, &rect);
*/

}


void
clear_drawing_area (GtkWidget *widget,
					GdkPixmap *pixmap)
{
	gdk_draw_rectangle (pixmap,
						widget->style->white_gc,
						TRUE, 0, 0,
						widget->allocation.width,
						widget->allocation.height);
}
